Documentation
¶
Index ¶
- Variables
- type App
- type Page
- func (p *Page) AddContainer(parent string, name string, direction int, size int, proportion int, ...) error
- func (p *Page) AddItem(container string, name string, item interface{}, size int, proportion int, ...) error
- func (p *Page) GetContainer(name string) (*tview.Flex, error)
- func (p *Page) GetElemBox(name string) (*tview.Box, error)
- func (p *Page) GetElemButton(name string) (*tview.Button, error)
- func (p *Page) GetElemCheckbox(name string) (*tview.Checkbox, error)
- func (p *Page) GetElemDropDown(name string) (*tview.DropDown, error)
- func (p *Page) GetElemFlex(name string) (*tview.Flex, error)
- func (p *Page) GetElemForm(name string) (*tview.Form, error)
- func (p *Page) GetElemFrame(name string) (*tview.Frame, error)
- func (p *Page) GetElemInputField(name string) (*tview.InputField, error)
- func (p *Page) GetElemList(name string) (*tview.List, error)
- func (p *Page) GetElemModal(name string) (*tview.Modal, error)
- func (p *Page) GetElemPages(name string) (*tview.Pages, error)
- func (p *Page) GetElemTable(name string) (*tview.Table, error)
- func (p *Page) GetElemTableCell(name string) (*tview.TableCell, error)
- func (p *Page) GetElemTextView(name string) (*tview.TextView, error)
- func (p *Page) RemoveContainer(parent string, name string) error
- func (p *Page) RemoveItem(container string, name string) error
- func (p *Page) SetContainerDirection(container string, direction int) error
- type Pages
- type Toolbar
Constants ¶
This section is empty.
Variables ¶
var ( ErrContainerNotFound = errors.New("Container not found") ErrElemNotFound = errors.New("Element not found") ErrElemIncorrectType = errors.New("Element incorrect type") )
var (
ErrPageNotFound = errors.New("Page not found")
)
Functions ¶
This section is empty.
Types ¶
type App ¶
type App struct {
*tview.Application
// contains filtered or unexported fields
}
func (*App) GetToolbar ¶
type Page ¶
type Page struct {
*tview.Flex
Name string
Data interface{}
// contains filtered or unexported fields
}
func (*Page) AddContainer ¶
func (*Page) GetElemInputField ¶
func (p *Page) GetElemInputField(name string) (*tview.InputField, error)
func (*Page) GetElemTableCell ¶
type Pages ¶
type Pages struct {
*tview.Pages
// Current selected page
CurrentPage string
// contains filtered or unexported fields
}
Page is a embedded type of tview.Page with 2 more fields: the current selected page and a page list
func (*Pages) GetPage ¶
GetPage returns the page corresponding to the given name if the page is in tview.Pages slice and page list
func (*Pages) RemovePage ¶
RemovePage deletes the page corresponding to the given name if it exists
func (*Pages) SwitchToNextPage ¶
func (p *Pages) SwitchToNextPage()
SwitchToNextPage switchs to the next page of the current page
func (*Pages) SwitchToPage ¶
SwitchToPage switchs to the page corresponding to the given name
func (*Pages) SwitchToPrevPage ¶
func (p *Pages) SwitchToPrevPage()
SwitchToPrevPage switchs to the prev page of the current page
Click to show internal directories.
Click to hide internal directories.